@@ -1,6 +1,6 @@
 class CacheSys:
 
-    def BasicCache(name=str, content=str, dst=any):
+    def WriteCache(name=str, content=str, dst=any):
         """
         name = File name (include extension),
         content = Contents to put in the file,
@@ -24,4 +24,18 @@ class CacheSys:
         del os
         del exists
 
-        return 0
\ No newline at end of file
+        return 0
+    
+    def ReadCache(name=str, src=any):
+        """
+        name = File name (include extension),
+        src = File location (do not include the file name)
+        """
+
+        a = open(f"{src}/{name}", "r")
+
+        b = a.read()
+
+        a.close()
+
+        return b
\ No newline at end of file
